==> dde-shell_0.0.40.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="162"/>
        <source>Indicator Style</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="164"/>
        <source>Fashion Mode</source>
        <translation>Современный Режим</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="169"/>
        <source>Efficient Mode</source>
        <translation>Эффективный Режим</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="175"/>
        <source>Alignment</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="206"/>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="194"/>
        <source>Position</source>
        <translation>Положение</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="179"/>
        <source>Align Left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="181"/>
        <source>Align Top</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="188"/>
        <source>Align Center</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="196"/>
        <source>Top</source>
        <translation>Сверху</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="201"/>
        <source>Bottom</source>
        <translation>Снизу</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="211"/>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="217"/>
        <source>Status</source>
        <translation>Состояние</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="219"/>
        <source>Keep Shown</source>
        <translation>Отображать Всегда</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="224"/>
        <source>Keep Hidden</source>
        <translation>Держать Скрытым</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="230"/>
        <source>Smart Hide</source>
        <translation>Умное Скрытие</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="237"/>
        <source>Dock Settings</source>
        <translation>Настройки Dock</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.36.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Стиль индикатора</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Современный Режим</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Эффективный Режим</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Классический режим</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Режим центрирования</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Положение</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Сверху</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Снизу</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Состояние</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Отображать Всегда</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Держать Скрытым</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Умное Скрытие</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Настройки Dock</translation>
    </message>
</context>
</TS>
